@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package DNS::Oterica::RecordMaker::TinyDNS;
 # ABSTRACT: a tinydns recordmaker for DNSO.
-$DNS::Oterica::RecordMaker::TinyDNS::VERSION = '0.303';
+$DNS::Oterica::RecordMaker::TinyDNS::VERSION = '0.304';
 #pod =head1 DESCRIPTION
 #pod
 #pod This role provides logic for generating lines for the F<tinydns-data> program
@@ -375,7 +375,8 @@ sub dkim {
 
   my $tags = $rec->{tags};
   my $name = "$rec->{selector}._domainkey.$rec->{domain}";
-  my $text = join q{; }, map {; "$_=$tags->{$_}" } sort keys %$tags;
+  my $text = join q{; }, map {; "$_=$tags->{$_}" }
+             sort { $a eq 'v' ? -1 : $b eq 'v' ? 1 : ($a cmp $b) } keys %$tags;
 
   # We can't use ->txt because tinydns will split TXT records (generated by ')
   # up into 127b chunks.  DKIM doesn't let you do that. -- rjbs, 2016-10-04
@@ -400,7 +401,7 @@ DNS::Oterica::RecordMaker::TinyDNS - a tinydns recordmaker for DNSO.
 
 =head1 VERSION
 
-version 0.303
+version 0.304
 
 =head1 DESCRIPTION
 
